#ifndef NT2_INCLUDE_FUNCTIONS_SAFE_MAX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SAFE_MAX_HPP_INCLUDED

#include <nt2/ieee/include/functions/safe_max.hpp>

#endif
